;;; guile-irrlicht --- FFI bindings for Irrlicht Engine
;;; Copyright (C) 2020 Javier Sancho <jsf@jsancho.org>
;;;
;;; This file is part of guile-irrlicht.
;;;
;;; Guile-irrlicht is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU Lesser General Public License as
;;; published by the Free Software Foundation; either version 3 of the
;;; License, or (at your option) any later version.
;;;
;;; Guile-irrlicht is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;;; General Public License for more details.
;;;
;;; You should have received a copy of the GNU Lesser General Public
;;; License along with guile-irrlicht.  If not, see
;;; <http://www.gnu.org/licenses/>.


(define-module (irrlicht irr)
  #:use-module (oop goops)
  #:use-module (irrlicht base)
  #:use-module (irrlicht foreign))


;; IReferenceCounted
(define-class <reference-counted> (<irrlicht-base>)
  (irr-class #:init-value "IReferenceCounted"))

(define-method (drop! (obj <reference-counted>))
  (let ((drop (get-irrlicht-proc "drop" obj)))
    (drop obj)))

(export <reference-counted> drop!)


;; SEvent
(define-class <event> (<irrlicht-base>)
  (irr-class #:init-value "SEvent"))

(define-method (get-event-gui-caller (event <event>))
  (let ((SGUIEvent_Caller (get-irrlicht-proc "SGUIEvent_Caller" event)))
    (remember-wrapped (SGUIEvent_Caller event))))

(define-method (get-event-gui-type (event <event>))
  (let ((SGUIEvent_EventType (get-irrlicht-proc "SGUIEvent_EventType" event)))
    (SGUIEvent_EventType event)))

(define-method (get-event-key (event <event>))
  (let ((SKeyInput_Key (get-irrlicht-proc "SKeyInput_Key" event)))
    (SKeyInput_Key event)))

(define-method (get-event-key-pressed (event <event>))
  (let ((SKeyInput_PressedDown (get-irrlicht-proc "SKeyInput_PressedDown" event)))
    (SKeyInput_PressedDown event)))

(define-method (get-event-type (event <event>))
  (let ((EventType (get-irrlicht-proc "EventType" event)))
    (EventType event)))

(export <event> get-event-gui-caller get-event-gui-type get-event-key get-event-key-pressed
        get-event-type)


;; IEventReceiver
(define-class <event-receiver> (<irrlicht-base>)
  (irr-class #:init-value "IEventReceiver"))

(define (make-event-receiver proc-on-event)
  (let ((IEventReceiver_make (get-irrlicht-proc "IEventReceiver_make")))
    (IEventReceiver_make proc-on-event)))

(export <event-receiver> make-event-receiver)


;; SKeyMap
(define-class <key-map> (<irrlicht-base>)
  (irr-class #:init-value "SKeyMap"))

(export <key-map>)


;; ITimer
(define-class <timer> (<reference-counted>)
  (irr-class #:init-value "ITimer"))

(define-method (get-time (timer <timer>))
  (let ((getTime (get-irrlicht-proc "getTime" timer)))
    (getTime timer)))

(export <timer> get-time)
