/* guile-irrlicht --- GNU Guile bindings for Irrlicht Engine

   Copyright (C) 2020 Javier Sancho <jsf@jsancho.org>

   This file is part of guile-irrlicht.

   guile-irrlicht is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
   published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   guile-irrlicht is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with guile-irrlicht. If not, see
   <http://www.gnu.org/licenses/>.
*/

#include <irrlicht/irrlicht.h>
#include <libguile.h>
#include "box3d.h"
#include "gsubr.h"
#include "vector3d.h"
#include "wrapped.h"

using namespace irr;

SCM
aabbox3d_addInternalPoint (SCM box3d,
                           SCM point)
{
  ((core::aabbox3df*)scm_to_irr_pointer (box3d))->addInternalPoint (scm_to_vector3df (point));
  return SCM_UNSPECIFIED;
}

SCM
aabbox3d_make ()
{
  core::aabbox3df* aabbox = new core::aabbox3df ();
  return scm_from_irr_pointer ("<box3d>", (void*) aabbox);
}

SCM
aabbox3d_reset (SCM box3d,
                SCM init_value)
{
  ((core::aabbox3df*)scm_to_irr_pointer (box3d))->reset (scm_to_vector3df (init_value));
  return SCM_UNSPECIFIED;
}

void
init_box3d (void)
{
  DEFINE_GSUBR ("aabbox3d_addInternalPoint", 2, 0, 0, aabbox3d_addInternalPoint);
  DEFINE_GSUBR ("aabbox3d_make", 0, 0, 0, aabbox3d_make);
  DEFINE_GSUBR ("aabbox3d_reset", 2, 0, 0, aabbox3d_reset);
}
