/* guile-irrlicht --- GNU Guile bindings for Irrlicht Engine

   Copyright (C) 2020 Javier Sancho <jsf@jsancho.org>

   This file is part of guile-irrlicht.

   guile-irrlicht is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
   published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   guile-irrlicht is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with guile-irrlicht. If not, see
   <http://www.gnu.org/licenses/>.
*/

#include <irrlicht/irrlicht.h>
#include <libguile.h>

using namespace irr;

video::E_MATERIAL_FLAG
scm_to_material_flag (SCM material_flag)
{
  char* flag_name = scm_to_utf8_string (scm_symbol_to_string (material_flag));
  video::E_MATERIAL_FLAG flag;

  if (!strcmp (flag_name, "wireframe"))
    {
      flag = video::EMF_WIREFRAME;
    }
  else if (!strcmp (flag_name, "pointcloud"))
    {
      flag = video::EMF_POINTCLOUD;
    }
  else if (!strcmp (flag_name, "gouraud-shading"))
    {
      flag = video::EMF_GOURAUD_SHADING;
    }
  else if (!strcmp (flag_name, "lighting"))
    {
      flag = video::EMF_LIGHTING;
    }
  else if (!strcmp (flag_name, "zbuffer"))
    {
      flag = video::EMF_ZBUFFER;
    }
  else if (!strcmp (flag_name, "zwrite-enable"))
    {
      flag = video::EMF_ZWRITE_ENABLE;
    }
  else if (!strcmp (flag_name, "back-face-culling"))
    {
      flag = video::EMF_BACK_FACE_CULLING;
    }
  else if (!strcmp (flag_name, "front-face-culling"))
    {
      flag = video::EMF_FRONT_FACE_CULLING;
    }
  else if (!strcmp (flag_name, "bilinear-filter"))
    {
      flag = video::EMF_BILINEAR_FILTER;
    }
  else if (!strcmp (flag_name, "trilinear-filter"))
    {
      flag = video::EMF_TRILINEAR_FILTER;
    }
  else if (!strcmp (flag_name, "anisotropic-filter"))
    {
      flag = video::EMF_ANISOTROPIC_FILTER;
    }
  else if (!strcmp (flag_name, "fog-enable"))
    {
      flag = video::EMF_FOG_ENABLE;
    }
  else if (!strcmp (flag_name, "normalize-normals"))
    {
      flag = video::EMF_NORMALIZE_NORMALS;
    }
  else if (!strcmp (flag_name, "texture-wrap"))
    {
      flag = video::EMF_TEXTURE_WRAP;
    }
  else if (!strcmp (flag_name, "anti-aliasing"))
    {
      flag = video::EMF_ANTI_ALIASING;
    }
  else if (!strcmp (flag_name, "color-mask"))
    {
      flag = video::EMF_COLOR_MASK;
    }
  else if (!strcmp (flag_name, "color-material"))
    {
      flag = video::EMF_COLOR_MATERIAL;
    }
  else if (!strcmp (flag_name, "use-mip-maps"))
    {
      flag = video::EMF_USE_MIP_MAPS;
    }
  else if (!strcmp (flag_name, "blend-operation"))
    {
      flag = video::EMF_BLEND_OPERATION;
    }
  else if (!strcmp (flag_name, "polygon-offset"))
    {
      flag = video::EMF_POLYGON_OFFSET;
    }
  else
    {
      scm_error (scm_arg_type_key, NULL, "Wrong material flag: ~S",
                 scm_list_1 (material_flag), scm_list_1 (material_flag));
    }

  free (flag_name);
  return flag;
}
